@@ -68,6 +68,7 @@ pub(crate) enum TypePosition {
     FnArg(HostLang),
     FnReturn(HostLang),
     SharedStructField,
+    SwiftCallsRustAsyncOnCompleteReturnTy,
 }
 
 #[derive(Debug, PartialEq, Clone)]
@@ -155,6 +156,12 @@ impl ToTokens for PointerKind {
     }
 }
 
+impl BridgedType {
+    pub fn is_null(&self) -> bool {
+        matches!(self, BridgedType::StdLib(StdLibType::Null))
+    }
+}
+
 #[cfg(test)]
 impl BridgedType {
     fn unwrap_stdlib(&self) -> &StdLibType {
@@ -546,9 +553,10 @@ impl BridgedType {
                         }
                     },
                     BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Struct(
-                        _shared_struct,
+                        shared_struct,
                     ))) => {
-                        todo!("Option<SharedStruct> is not yet supported")
+                        let name = shared_struct.ffi_option_name_tokens();
+                        quote! { #name }
                     }
                     BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(
                         shared_enum,
@@ -659,6 +667,9 @@ impl BridgedType {
                             //
                             unimplemented!()
                         }
+                        TypePosition::SwiftCallsRustAsyncOnCompleteReturnTy => {
+                            unimplemented!()
+                        }
                     }
                 }
                 StdLibType::Null => "()".to_string(),
@@ -672,11 +683,17 @@ impl BridgedType {
                     }
                     TypePosition::FnReturn(_func_host_lang) => "RustStr".to_string(),
                     TypePosition::SharedStructField => "RustStr".to_string(),
+                    TypePosition::SwiftCallsRustAsyncOnCompleteReturnTy => {
+                        unimplemented!()
+                    }
                 },
                 StdLibType::String => match type_pos {
                     TypePosition::FnArg(_func_host_lang) => "GenericIntoRustString".to_string(),
                     TypePosition::FnReturn(_func_host_lang) => "RustString".to_string(),
                     TypePosition::SharedStructField => "RustString".to_string(),
+                    TypePosition::SwiftCallsRustAsyncOnCompleteReturnTy => {
+                        unimplemented!()
+                    }
                 },
                 StdLibType::Vec(ty) => {
                     format!("RustVec<{}>", ty.ty.to_swift_type(type_pos))
@@ -693,6 +710,9 @@ impl BridgedType {
                     TypePosition::SharedStructField => {
                         format!("Optional<{}>", opt.ty.to_swift_type(type_pos))
                     }
+                    TypePosition::SwiftCallsRustAsyncOnCompleteReturnTy => {
+                        unimplemented!()
+                    }
                 },
             },
             BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Struct(shared_struct))) => {
@@ -706,6 +726,9 @@ impl BridgedType {
                         }
                     }
                     TypePosition::SharedStructField => shared_struct.swift_name_string(),
+                    TypePosition::SwiftCallsRustAsyncOnCompleteReturnTy => {
+                        shared_struct.ffi_name_string()
+                    }
                 }
             }
             BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(shared_enum))) => {
@@ -719,6 +742,9 @@ impl BridgedType {
                         }
                     }
                     TypePosition::SharedStructField => shared_enum.swift_name_string(),
+                    TypePosition::SwiftCallsRustAsyncOnCompleteReturnTy => {
+                        unimplemented!()
+                    }
                 }
             }
             BridgedType::Foreign(CustomBridgedType::Opaque(opaque)) => {
@@ -746,6 +772,9 @@ impl BridgedType {
                             //
                             unimplemented!()
                         }
+                        TypePosition::SwiftCallsRustAsyncOnCompleteReturnTy => {
+                            unimplemented!()
+                        }
                     }
                 } else {
                     match type_pos {
@@ -761,6 +790,9 @@ impl BridgedType {
                             //
                             unimplemented!()
                         }
+                        TypePosition::SwiftCallsRustAsyncOnCompleteReturnTy => {
+                            unimplemented!()
+                        }
                     }
                 }
             }
@@ -1092,6 +1124,9 @@ impl BridgedType {
                             TypePosition::SharedStructField => {
                                 format!("UnsafeRawPointer({}!)", value)
                             }
+                            TypePosition::SwiftCallsRustAsyncOnCompleteReturnTy => {
+                                unimplemented!()
+                            }
                         },
                         PointerKind::Mut => value.to_string(),
                     },
@@ -1186,6 +1221,9 @@ impl BridgedType {
                         TypePosition::SharedStructField => {
                             todo!("Pointers in shared struct fields are not yet supported")
                         }
+                        TypePosition::SwiftCallsRustAsyncOnCompleteReturnTy => {
+                            unimplemented!()
+                        }
                     },
                 },
                 StdLibType::Str => match type_pos {
@@ -1200,6 +1238,9 @@ impl BridgedType {
                     TypePosition::SharedStructField => {
                         todo!("&str in shared struct fields is not yet supported")
                     }
+                    TypePosition::SwiftCallsRustAsyncOnCompleteReturnTy => {
+                        unimplemented!()
+                    }
                 },
                 StdLibType::String => {
                     format!(
@@ -1249,6 +1290,9 @@ impl BridgedType {
                             TypePosition::SharedStructField => {
                                 todo!("Opaque types in shared struct fields are not yet supported")
                             }
+                            TypePosition::SwiftCallsRustAsyncOnCompleteReturnTy => {
+                                unimplemented!()
+                            }
                         }
                     }
                 } else {
@@ -1271,6 +1315,9 @@ impl BridgedType {
                         TypePosition::SharedStructField => {
                             todo!("Opaque types in shared struct fields are not yet supported")
                         }
+                        TypePosition::SwiftCallsRustAsyncOnCompleteReturnTy => {
+                            unimplemented!()
+                        }
                     }
                 }
             }
@@ -1376,8 +1423,12 @@ impl BridgedType {
                     todo!("Support nested Option<Option<T>>")
                 }
             },
-            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Struct(_shared_struct))) => {
-                todo!("Support Option<SharedStruct>")
+            BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Struct(shared_struct))) => {
+                let option_name = shared_struct.ffi_option_name_tokens();
+                UnusedOptionNoneValue {
+                    rust: quote! { #option_name { is_some: false, val: std::mem::MaybeUninit::uninit() } },
+                    swift: "TODO..Support Swift Option<Enum>::None value".into(),
+                }
             }
             BridgedType::Foreign(CustomBridgedType::Shared(SharedType::Enum(shared_enum))) => {
                 let option_name = shared_enum.ffi_option_name_tokens();
