@@ -188,7 +188,7 @@ fn generate_swift_class(
             r#"public class {type_name}: {type_name}RefMut {{
     var isOwned: Bool = true
 
-    override init(ptr: UnsafeMutableRawPointer) {{
+    public override init(ptr: UnsafeMutableRawPointer) {{
         super.init(ptr: ptr)
     }}
 
@@ -208,7 +208,7 @@ fn generate_swift_class(
         format!(
             r#"
 public class {type_name}RefMut: {type_name}Ref {{
-    override init(ptr: UnsafeMutableRawPointer) {{
+    public override init(ptr: UnsafeMutableRawPointer) {{
         super.init(ptr: ptr)
     }}
 }}"#,
@@ -223,7 +223,7 @@ public class {type_name}RefMut: {type_name}Ref {{
 public class {type_name}Ref {{
     var ptr: UnsafeMutableRawPointer
 
-    init(ptr: UnsafeMutableRawPointer) {{
+    public init(ptr: UnsafeMutableRawPointer) {{
         self.ptr = ptr
     }}
 }}"#,
@@ -404,9 +404,9 @@ fn gen_func_swift_calls_rust(
     };
 
     let swift_class_func_name = if function.is_swift_initializer {
-        "convenience init".to_string()
+        "public convenience init".to_string()
     } else {
-        format!("func {}", fn_name.as_str())
+        format!("public func {}", fn_name.as_str())
     };
 
     let indentation = if function.associated_type.is_some() {
@@ -574,7 +574,7 @@ fn gen_func_swift_calls_rust(
             r#"class CbWrapper {{
     var cb: (Result<{rust_fn_ret_ty}, Never>) -> ()
 
-    init(cb: @escaping (Result<{rust_fn_ret_ty}, Never>) -> ()) {{
+    public init(cb: @escaping (Result<{rust_fn_ret_ty}, Never>) -> ()) {{
         self.cb = cb
     }}
 }}
@@ -734,7 +734,7 @@ mod tests {
         let generated = module.generate_swift(&CodegenConfig::no_features_enabled());
 
         let expected = r#"
-func foo() {
+public func foo() {
     __swift_bridge__$foo()
 } 
 "#;
@@ -826,7 +826,7 @@ func __swift_bridge__MyType_foo (_ this: UnsafeMutableRawPointer) -> __private__
         let generated = module.generate_swift(&CodegenConfig::no_features_enabled());
 
         let expected = r#"
-func foo(_ bar: UInt8) {
+public func foo(_ bar: UInt8) {
     __swift_bridge__$foo(bar)
 } 
 "#;
@@ -849,7 +849,7 @@ func foo(_ bar: UInt8) {
         let generated = module.generate_swift(&CodegenConfig::no_features_enabled());
 
         let expected = r#"
-func foo() -> UInt32 {
+public func foo() -> UInt32 {
     __swift_bridge__$foo()
 } 
 "#;
@@ -906,7 +906,7 @@ func __swift_bridge__Foo__free (ptr: UnsafeMutableRawPointer) {
     /// Verify that we generated a function that Rust can use to reduce a Swift class instance's
     /// reference count.
     #[test]
-    fn extern_swift_claas_init() {
+    fn extern_swift_class_init() {
         let tokens = quote! {
             mod foo {
                 extern "Swift" {
@@ -950,7 +950,7 @@ func __swift_bridge__Foo_new (_ a: UInt8) -> __private__PointerToSwiftType {
 public class Foo: FooRefMut {
     var isOwned: Bool = true
 
-    override init(ptr: UnsafeMutableRawPointer) {
+    public override init(ptr: UnsafeMutableRawPointer) {
         super.init(ptr: ptr)
     }
 
@@ -961,7 +961,7 @@ public class Foo: FooRefMut {
     }
 }
 extension Foo {
-    convenience init() {
+    public convenience init() {
         self.init(ptr: __swift_bridge__$Foo$new())
     }
 }
@@ -990,7 +990,7 @@ extension Foo {
 public class Foo: FooRefMut {
     var isOwned: Bool = true
 
-    override init(ptr: UnsafeMutableRawPointer) {
+    public override init(ptr: UnsafeMutableRawPointer) {
         super.init(ptr: ptr)
     }
 
@@ -1001,7 +1001,7 @@ public class Foo: FooRefMut {
     }
 }
 extension Foo {
-    convenience init(_ val: UInt8) {
+    public convenience init(_ val: UInt8) {
         self.init(ptr: __swift_bridge__$Foo$new(val))
     }
 }
@@ -1061,12 +1061,12 @@ func __swift_bridge__Foo_pop (_ this: UnsafeMutableRawPointer) {
 public class FooRef {
     var ptr: UnsafeMutableRawPointer
 
-    init(ptr: UnsafeMutableRawPointer) {
+    public init(ptr: UnsafeMutableRawPointer) {
         self.ptr = ptr
     }
 }
 extension FooRef {
-    func bar() -> UInt8 {
+    public func bar() -> UInt8 {
         __swift_bridge__$Foo$bar(ptr)
     }
 }
@@ -1094,12 +1094,12 @@ extension FooRef {
 public class FooRef {
     var ptr: UnsafeMutableRawPointer
 
-    init(ptr: UnsafeMutableRawPointer) {
+    public init(ptr: UnsafeMutableRawPointer) {
         self.ptr = ptr
     }
 }
 extension FooRef {
-    func bar(_ other: FooRef) {
+    public func bar(_ other: FooRef) {
         __swift_bridge__$Foo$bar(ptr, other.ptr)
     }
 }
@@ -1128,12 +1128,12 @@ extension FooRef {
 public class FooRef {
     var ptr: UnsafeMutableRawPointer
 
-    init(ptr: UnsafeMutableRawPointer) {
+    public init(ptr: UnsafeMutableRawPointer) {
         self.ptr = ptr
     }
 }
 extension FooRef {
-    class func bar() {
+    class public func bar() {
         __swift_bridge__$Foo$bar()
     }
 }
@@ -1183,7 +1183,7 @@ func __swift_bridge__Foo_bar (_ arg: UInt8) {
         let generated = module.generate_swift(&CodegenConfig::no_features_enabled());
 
         let expected = r#"
-func foo() -> RustString {
+public func foo() -> RustString {
     RustString(ptr: __swift_bridge__$foo())
 }
 "#;
